using System.Collections.Generic;
using DaggerfallConnect;
using DaggerfallWorkshop;
using DaggerfallWorkshop.Game;
using DaggerfallWorkshop.Game.Entity;
using DaggerfallWorkshop.Game.UserInterface;
using DaggerfallWorkshop.Game.UserInterfaceWindows;
using UnityEngine;

namespace ViewableSkillProgress
{
    public class VSPCharacterSheetOverride : DaggerfallCharacterSheetWindow
    {

        #region Constructors

        public VSPCharacterSheetOverride(IUserInterfaceManager uiManager)
            : base(uiManager)
        {
        }

        #endregion


        protected override void Setup()
        {
            base.Setup();

            /* ----Temporarily disabling, might be needed later
             
            //The Level button needs to be modified but it isn't exposed in the base class.
            //We'll just remove the button and add a replacement. (Unfortunate hack)
            bool buttonRemoved = false;

            foreach (BaseScreenComponent component in NativePanel.Components)
            {
                if (component is Button)
                {
                    if (component.Position.x == 4 && component.Position.y == 33)
                    {
                        //this appears to be the Level button
                        NativePanel.Components.Remove(component);
                        buttonRemoved = true;
                        break;
                    }
                }
            }

            if (buttonRemoved)
            {
                //replacing old Level up button with a new one
                Button levelButton = DaggerfallUI.AddButton(new Rect(4, 33, 132, 8), NativePanel);
                levelButton.OnMouseClick += LevelButton_OnMouseClick;
                levelButton.Hotkey = DaggerfallShortcut.GetBinding(DaggerfallShortcut.Buttons.CharacterSheetLevel);
            }

            */

        }


        protected override void ShowSkillsDialog(List<DFCareer.Skills> skills, bool twoColumn = false)
        {
            SkillsWindow skillsWindow = new SkillsWindow(uiManager, this);
            skillsWindow.Show(skills, twoColumn);
        }


        private void LevelButton_OnMouseClick(BaseScreenComponent sender, Vector2 position)
        {
            DaggerfallUI.Instance.PlayOneShot(SoundClips.ButtonClick);

            PlayerEntity player = GameManager.Instance.PlayerEntity;

            float currentLevel = (player.CurrentLevelUpSkillSum - player.StartingLevelUpSkillSum + 28f) / 15f;
            int progress = (int)((currentLevel % 1) * 100);
            DaggerfallUI.MessageBox(string.Format(TextManager.Instance.GetLocalizedText("levelProgress"), progress));
        }


    }
}
